[![Build Status](https://travis-ci.com/clawpack/pyclaw.svg?branch=master)](https://travis-ci.com/clawpack/pyclaw)
[![Coverage Status](https://img.shields.io/coveralls/clawpack/pyclaw.svg)](https://coveralls.io/r/clawpack/pyclaw?branch=master)

[![PyPI version](https://badge.fury.io/py/clawpack.svg)](https://badge.fury.io/py/clawpack)


# PyClaw

Pyclaw is a Python-based solver for hyperbolic PDEs that includes the algorithms
of Clawpack and SharpClaw.  
It has been designed with easy extensibility, performance, and exploration in mind.
PyClaw also includes a scalable parallel implementation of Clawpack using PETSc.

Documentation is available at http://clawpack.org/pyclaw/.

If you use PyClaw in research that leads to publication, please
[cite PyClaw](http://www.clawpack.org/pyclaw/index.html#citing-pyclaw)
(see also [citing Clawpack](http://www.clawpack.org/about.html#citing-this-work)).
